#!/usr/bin/env bash

# Source function library.
. /etc/init.d/functions

. /lib/lsb/init-functions

NAME="mesos-master"
DESC="mesos-master"
command="$NAME"

BASEMAPR=${MAPR_HOME:-/opt/mapr}
PATH=$PATH:/sbin:/usr/sbin:/bin:/usr/bin
PIDFILE=${BASEMAPR}/pid/mesos-master.pid
DIRNAME=`dirname $0`
MASTERINITLOG=${DIRNAME}/../logs/mesos-master-init.log

start() {
  
  status $NAME 
  if [ "$?" == "0" ]; then
    echo $command running. Stop it
    return 1
  fi

  /usr/bin/mesos-init-wrapper master >> $MASTERINITLOG 2>&1 &
}

stop() {
    #
    # REMINDER: If the parameters for killproc should
    # change in this function, then the parameters need
    # to be verified against SuSE in order to maintian
    # support.
    #
    local delay="-d 10"

    if [ -f "/etc/SuSE-release" ]; then
        delay="-t 10"
    fi

    #
    # killproc needs -p before -d !
    #
    if [ -f "${PIDFILE}" ]; then
        killproc -p ${PIDFILE} ${delay} ${NAME}
        killproc ${delay} ${NAME}
    else
        killproc ${delay} ${NAME}
    fi

    rm -f ${PIDFILE}

  return 0
}

case "${1-}" in
  start)
     echo -n "Starting $DESC: "
     start
     echo "$NAME."
     ;;
  stop)
     echo -n "Stopping $DESC: "
     stop
     echo "$NAME."
     ;;
  restart)
     echo -n "Restarting $DESC: "
     stop
     sleep 1
     start
     echo "$NAME."
     ;;
  status)
     status "$NAME" 
     ;;
  *)
     echo "Usage: $0 {start|stop|restart|status}" >&2
     exit 1
     ;;
 esac
